@@ -3,8 +3,8 @@ Inspiration for the syntax was taken from SQLALchemy.
 Querying and creating are supported.
 """
 
-__all__ = ['FTrackQuery', 'entity', 'and_', 'or_']
-__version__ = '1.3.3'
+__all__ = ['FTrackQuery', 'entity', 'and_', 'or_', 'not_']
+__version__ = '1.4.4'
 
 import logging
 import os
@@ -87,7 +87,6 @@ def parse_inputs(*args, **kwargs):
         This is the recommended way to query if possible.
     """
 
-    comparison = kwargs.pop('__cmp__', 'is')
     for arg in args:
         # The query has not been performed, attempt to execute
         # This shouldn't really be used, so don't catch any errors
@@ -98,14 +97,8 @@ def parse_inputs(*args, **kwargs):
             for key, value in arg.items():
                 yield Comparison(key)==value
 
-        # Attempt to convert entity to lowercase name with ID
-        # For example, "<Project>" will evaluate to 'project.id is "<Project['id']>"'
         elif isinstance(arg, ftrack_api.entity.base.Entity):
-            yield ' '.join([
-                get_key_from_entity(arg)+'.id',
-                comparison,
-                convert_output_value(arg['id'])
-            ])
+            raise TypeError("keyword required for {}".format(arg))
 
         # The object is likely a comparison object, so convert to str
         # If an actual string is input, then assume it's valid syntax
@@ -118,22 +111,6 @@ def parse_inputs(*args, **kwargs):
         yield Comparison(key)==value
 
 
-_UC_REMAP = {u: '_'+l for l, u in zip(ascii_lowercase, ascii_uppercase)}
-def get_key_from_entity(entity):
-    """Guess the attribute that would be given to an entity.
-    This is done by converting UpperCase to lower_case.
-
-    Ideally this shouldn't ever be called, but in some cases it can
-    make sense. Instead of "Task.where(project=project)", we can assume
-    the attribute is "project", and write it as "Task.where(project)".
-    """
-    if isinstance(entity, ftrack_api.entity.base.Entity):
-        entity = entity.__class__.__name__
-    if entity == 'NoteLabel':
-        return 'category'
-    return ''.join(_UC_REMAP.get(c, c) for c in entity).lstrip('_')
-
-
 class Criteria(object):
     """Convert multiple arguments into a valid query."""
     def __init__(self, operator, brackets):
@@ -153,6 +130,11 @@ and_ = Criteria('and', brackets=False)
 or_ = Criteria('or', brackets=True)
 
 
+def not_(comparison):
+    """Reverse a comparison object."""
+    return ~ comparison
+
+
 class Comparison(object):
     """Deal with individual query comparisons."""
     def __init__(self, value):
@@ -171,6 +153,8 @@ class Comparison(object):
         return self.value
 
     def __invert__(self):
+        if self.value[:4] == 'not ':
+            return self.__class__(self.value[4:])
         return self.__class__('not '+self.value)
 
     def __getitem__(self, value):
@@ -267,10 +251,31 @@ class Comparison(object):
         where = parse_inputs(*args, **kwargs)
         return self.__class__('{} any ({})'.format(self.value, and_(*where)))
 
+    def in_(self, *args):
+        """The in operator works slightly differently to the others.
+        It supports subqueries (x in (select y from z)), and multiple
+        items (x in ("y", "z")).
+        Since quotation marks are important, this method assumes that
+        a single argument is a subquery, and multiple arguments are a
+        list of possible values.
+        """
+        if len(args) == 1:
+            subquery = args[0]
+        else:
+            subquery = ', '.join(map(convert_output_value, args))
+        return self.__class__('{} in ({})'.format(self.value, subquery))
+
+    def not_in(self, *args):
+        return ~self.in_(*args)
+
 
 class Query(object):
     """Base class for constructing a query."""
     _EntityKeyCache = {}
+    _PrimaryKeys = {
+        'User': 'username',
+    }
+
     def __init__(self, session, entity):
         self._session = session
         self._entity = entity
@@ -318,7 +323,17 @@ class Query(object):
     def __call__(self, *args, **kwargs):
         """Custom error message if attempting to call.
         This is due to it being quite a common mistake.
+
+        In rare cases, it can be valid to pass in a single argument,
+        such as User('username'). The inspiration for this was taken
+        from the old API.
         """
+        if self._entity in self._PrimaryKeys and len(args) == 1 and not kwargs:
+            try:
+                return self.where(**{self._PrimaryKeys[self._entity]: args[0]}).one()
+            except ftrack_api.exception.NoResultFoundError:
+                return None
+
         raise TypeError("'Query' object is not callable, "
                         "perhaps you meant to use 'Query.where()'?")
 
@@ -533,7 +548,20 @@ class FTrackQuery(ftrack_api.Session):
         return super(FTrackQuery, self).rollback(*args, **kwargs)
 
 
-# Quick access to a query object for comparisons
-# An example would be "session.Episode.where(entity.project.name=='Project')"
-# instead of "session.Episode.where(session.Episode.project.name=='Project')"
-entity = Query.new(None, None)
+class _Entity(object):
+    """Quick access to a basic query object for comparisons.
+
+    Example:
+        >>> session.Episode.where(session.Episode.project.name=='Project')
+        >>> session.Episode.where(entity.project.name=='Project')
+    """
+
+    def __init__(self):
+        self._query = Query.new(None, None)
+
+    def __getattr__(self, attr):
+        """Bypass the methods of Query to just get attributes."""
+        return self._query.__getattr__(attr)
+
+
+entity = _Entity()
